@@ -5,6 +5,8 @@ import os
 from uuid import uuid4
 from typing import List
 from .exceptions import ShellError
+from pathlib import Path
+from shutil import rmtree
 
 def fftsanitise(fftsettings) -> List[int]:
     return [
@@ -32,17 +34,27 @@ def odd_snap(number: int) -> int:
 def fftformat(fftsettings: List[int]) -> int:
     """Handles the FFT size so you can pass maxfftsize"""
     fftsize = fftsettings[2]
-    if  fftsize == -1:
+    if fftsize == -1:
         fftsize = fftsettings[0]
     return math.floor(2 ** math.ceil(math.log(fftsize)/math.log(2)))
 
-def make_temp() -> str:
-    """Convenience for creating unique temporary files"""
-    tmp = tempfile.mkdtemp()
-    uuid = str(uuid4().hex)
-    return os.path.join(tmp, f"{uuid}.wav")
-
 def handle_ret(retval: int):
     """Handle return value and raise exceptions if necessary"""
     if retval != 0:
         raise ShellError(retval)
+
+def make_temp() -> str:
+    """Create temporary files in local hidden directory"""
+    tempfiles = Path.home() / ".python-flucoma"
+    if not tempfiles.exists():
+        tempfiles.mkdir()
+    
+    uuid = str(uuid4().hex)
+    full_path = tempfiles / f"{uuid}.wav" 
+    return str(full_path)
+
+def cleanup():
+    tempfiles = Path.home() / ".python-flucoma"
+    if tempfiles.exists():
+        rmtree(tempfiles)
+    
